@@ -7,24 +7,24 @@ Created on 2015-8-8
 
 from PyFin.Analysis.DataProviders import DataProvider
 from PyFin.Analysis.SecurityValueHolders import SecurityShiftedValueHolder
-from PyFin.Analysis.SecurityValueHolders import SecurityWhereValueHolder
+from PyFin.Analysis.SecurityValueHolders import SecurityIIFValueHolder
 from PyFin.Analysis.CrossSectionValueHolders import CSRankedSecurityValueHolder
 from PyFin.Analysis.CrossSectionValueHolders import CSAverageSecurityValueHolder
 from PyFin.Analysis.CrossSectionValueHolders import CSAverageAdjustedSecurityValueHolder
 from PyFin.Analysis.CrossSectionValueHolders import CSQuantileSecurityValueHolder
+from PyFin.Analysis.CrossSectionValueHolders import CSZScoreSecurityValueHolder
 from PyFin.Analysis.SecurityValueHolders import SecurityLatestValueHolder
-from PyFin.Analysis.SecurityValueHolders import dependencyCalculator
 from PyFin.Analysis import TechnicalAnalysis
 from PyFin.Analysis.transformer import transform
 
 __all__ = ['DataProvider',
            'SecurityShiftedValueHolder',
-           'SecurityWhereValueHolder',
+           'SecurityIIFValueHolder',
            'CSRankedSecurityValueHolder',
            'CSAverageSecurityValueHolder',
            'CSAverageAdjustedSecurityValueHolder',
            'CSQuantileSecurityValueHolder',
+           'CSZScoreSecurityValueHolder',
            'SecurityLatestValueHolder',
-           'dependencyCalculator',
            'TechnicalAnalysis',
            'transform']
